==> munipack_0.5.9.orig.tar.gz: munipack-0.5.9/munipack/flat.cpp <==
/*

  Average of flats.

  Copyright © 2010-2014 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
  
  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "munipack.h"


bool Munipack::flat(MuniProcess *action, MuniCmdLineParser& cmd)
{
  CommonOutputSingle(action,cmd);
  CommonOptionsBitpix(action,cmd);

  double x;
  wxString a;

  if( cmd.Found("level",&x) )
    action->Write("LEVEL = %lf",x);

  if( cmd.Found("bias",&a) )
    action->Write("BIAS = '"+a+"'");

  if( cmd.Found("dark",&a) )
    action->Write("DARK = '"+a+"'");

  if( cmd.Found("xdark",&x) )
    action->Write("XDARK = %lf",x);

  if( cmd.Found("gain",&x) )
    action->Write("GAIN = %lf",x);

  if( cmd.Found("saturate",&x) )
    action->Write("SATURATE = %lf",x);

  if( cmd.Found("gain-estimate") ) {
    action->Write("GAIN_ESTIMATE = T");
    action->Write("VERBOSE = T");
  }

  for(size_t i = 0; i < cmd.GetParamCount(); i++)
    WriteFile(action,cmd.GetParam(i));

  return true;
}

==> munipack_0.5.10.orig.tar.gz: munipack-0.5.10/munipack/flat.cpp <==
/*

  Average of flats.

  Copyright © 2010-2014, 2017 F.Hroch (hroch@physics.muni.cz)

  This file is part of Munipack.

  Munipack is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  Munipack is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with Munipack.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "munipack.h"


bool Munipack::flat(MuniProcess *action, MuniCmdLineParser& cmd)
{
  CommonOutputSingle(action,cmd);
  CommonOptionsBitpix(action,cmd);

  double x;
  wxString a;

  if( cmd.Found("bias",&a) )
    action->Write("BIAS = '"+a+"'");

  if( cmd.Found("dark",&a) )
    action->Write("DARK = '"+a+"'");

  if( cmd.Found("xdark",&x) )
    action->Write("XDARK = %lf",x);

  if( cmd.Found("bitmask",&a) )
    action->Write("MASK = '"+a+"'");

  if( cmd.Found("gain",&x) )
    action->Write("GAIN = %lf",x);

  if( cmd.Found("st",&x) || cmd.Found("saturate",&x) )
    action->Write("SATURATE = %lf",x);

  if( cmd.Found("th",&x) || cmd.Found("threshold",&x) )
    action->Write("THRESHOLD = %lf",x);

  if( cmd.Found("gain-estimate") ) {
    action->Write("GAIN_ESTIMATE = T");
    action->Write("VERBOSE = T");
  }

  if( cmd.Found("approximation",&a) )
    action->Write("APPROXIMATION = '"+a+"'");

  for(size_t i = 0; i < cmd.GetParamCount(); i++)
    WriteFile(action,cmd.GetParam(i));

  return true;
}
